@@ -9,9 +9,12 @@ Notes :
 December 26, 2018
 """
 
+import os
 from types import MappingProxyType
 
-API_URL = 'https://api.stratodem.com/api'
+ROUTE_PREFIX = os.environ.get('API_ROUTE_PREFIX', 'api')
+
+API_URL = f'https://{ROUTE_PREFIX}.stratodem.com/api'
 
 MAX_RETRIES = 3
 
@@ -74,27 +77,61 @@ BUFFERS_TUPLE = (
     'one-mile',
     'two-mile',
     'three-mile',
+    'four-mile',
     'five-mile',
+    'six-mile',
     'seven-mile',
+    'eight-mile',
+    'nine-mile',
     'ten-mile',
+    'eleven-mile',
+    'twelve-mile',
+    'thirteen-mile',
+    'fourteen-mile',
+    'fifteen-mile',
+    'sixteen-mile',
+    'seventeen-mile',
+    'eighteen-mile',
+    'nineteen-mile',
+    'twenty-mile',
+    'twenty-five-mile',
+    'thirty-mile',
+    'fifty-mile',
+    'sixty-mile',
+    'five-min',
     'ten-min',
     'fifteen-min',
     'twenty-min',
     'thirty-min',
+    'forty-five-min',
+    'sixty-min',
+    'five-traffic',
     'ten-traffic',
     'fifteen-traffic',
     'twenty-traffic',
     'thirty-traffic',
+    'forty-five-traffic',
+    'sixty-traffic',
     'ten-walk',
     'fifteen-walk',
     'twenty-walk',
     'thirty-walk',
+    'five-min-destination',
     'ten-min-destination',
     'fifteen-min-destination',
     'twenty-min-destination',
     'thirty-min-destination',
+    'forty-five-min-destination',
+    'sixty-min-destination',
+    'five-traffic-destination',
     'ten-traffic-destination',
     'fifteen-traffic-destination',
     'twenty-traffic-destination',
     'thirty-traffic-destination',
+    'forty-five-traffic-destination',
+    'sixty-traffic-destination',
+    'ten-walk-destination',
+    'fifteen-walk-destination',
+    'twenty-walk-destination',
+    'thirty-walk-destination',
 )
